@@ -1058,6 +1058,16 @@ class SearchAllResourcesRequest(proto.Message):
             -  ``kmsKey:key`` to find Cloud resources encrypted with a
                customer-managed encryption key whose name contains the
                word "key".
+            -  ``relationships:instance-group-1`` to find Cloud
+               resources that have relationships with "instance-group-1"
+               in the related resource name.
+            -  ``relationships:INSTANCE_TO_INSTANCEGROUP`` to find
+               compute instances that have relationships of type
+               "INSTANCE_TO_INSTANCEGROUP".
+            -  ``relationships.INSTANCE_TO_INSTANCEGROUP:instance-group-1``
+               to find compute instances that have relationships with
+               "instance-group-1" in the compute instance group resource
+               name, for relationship type "INSTANCE_TO_INSTANCEGROUP".
             -  ``state:ACTIVE`` to find Cloud resources whose state
                contains "ACTIVE" as a word.
             -  ``NOT state:ACTIVE`` to find Cloud resources whose state
@@ -1257,8 +1267,8 @@ class SearchAllIamPoliciesRequest(proto.Message):
             IAM policy binding, including its principals, roles, and
             Cloud IAM conditions. The returned Cloud IAM policies will
             only contain the bindings that match your query. To learn
-            more about the IAM policy structure, see `IAM policy
-            doc <https://cloud.google.com/iam/docs/policies#structure>`__.
+            more about the IAM policy structure, see the `IAM policy
+            documentation <https://cloud.google.com/iam/help/allow-policies/structure>`__.
 
             Examples:
 
