@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -210,14 +210,13 @@ class AssetServiceAsyncClient:
         project/folder/organization to listen to its asset
         updates.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p2beta1
 
-            def sample_create_feed():
+            async def sample_create_feed():
                 # Create a client
-                client = asset_v1p2beta1.AssetServiceClient()
+                client = asset_v1p2beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 feed = asset_v1p2beta1.Feed()
@@ -230,7 +229,7 @@ class AssetServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_feed(request=request)
+                response = await client.create_feed(request=request)
 
                 # Handle the response
                 print(response)
@@ -301,7 +300,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -321,9 +325,9 @@ class AssetServiceAsyncClient:
 
             from google.cloud import asset_v1p2beta1
 
-            def sample_get_feed():
+            async def sample_get_feed():
                 # Create a client
-                client = asset_v1p2beta1.AssetServiceClient()
+                client = asset_v1p2beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = asset_v1p2beta1.GetFeedRequest(
@@ -331,7 +335,7 @@ class AssetServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_feed(request=request)
+                response = await client.get_feed(request=request)
 
                 # Handle the response
                 print(response)
@@ -407,7 +411,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -424,14 +433,13 @@ class AssetServiceAsyncClient:
         r"""Lists all asset feeds in a parent
         project/folder/organization.
 
-
         .. code-block:: python
 
             from google.cloud import asset_v1p2beta1
 
-            def sample_list_feeds():
+            async def sample_list_feeds():
                 # Create a client
-                client = asset_v1p2beta1.AssetServiceClient()
+                client = asset_v1p2beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = asset_v1p2beta1.ListFeedsRequest(
@@ -439,7 +447,7 @@ class AssetServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.list_feeds(request=request)
+                response = await client.list_feeds(request=request)
 
                 # Handle the response
                 print(response)
@@ -510,7 +518,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -530,9 +543,9 @@ class AssetServiceAsyncClient:
 
             from google.cloud import asset_v1p2beta1
 
-            def sample_update_feed():
+            async def sample_update_feed():
                 # Create a client
-                client = asset_v1p2beta1.AssetServiceClient()
+                client = asset_v1p2beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 feed = asset_v1p2beta1.Feed()
@@ -543,7 +556,7 @@ class AssetServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_feed(request=request)
+                response = await client.update_feed(request=request)
 
                 # Handle the response
                 print(response)
@@ -612,7 +625,12 @@ class AssetServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -632,9 +650,9 @@ class AssetServiceAsyncClient:
 
             from google.cloud import asset_v1p2beta1
 
-            def sample_delete_feed():
+            async def sample_delete_feed():
                 # Create a client
-                client = asset_v1p2beta1.AssetServiceClient()
+                client = asset_v1p2beta1.AssetServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = asset_v1p2beta1.DeleteFeedRequest(
@@ -642,7 +660,7 @@ class AssetServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_feed(request=request)
+                await client.delete_feed(request=request)
 
         Args:
             request (Union[google.cloud.asset_v1p2beta1.types.DeleteFeedRequest, dict]):
@@ -705,7 +723,10 @@ class AssetServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def __aenter__(self):
@@ -717,7 +738,9 @@ class AssetServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-asset",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-asset",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
